

from flask import Flask, redirect, render_template, request, url_for
from flask_sqlalchemy import SQLAlchemy
from openpyxl import load_workbook
from wtforms import Form, IntegerField, StringField, SubmitField
from wtforms.validators import NumberRange

app = Flask(__name__)
app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///foo.db'
app.secret_key = 'qweqweqwe'

db = SQLAlchemy(app)

class Inventory(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    sort = db.Column(db.Integer)
    location = db.Column(db.Integer)
    tag = db.Column(db.Text)
    amount = db.Column(db.Integer)
    name = db.Column(db.Text)
    mtime = db.Column(db.Date)

with app.app_context():
    db.create_all()

class CheckForm(Form):

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.sort = IntegerField('sort')
        self.location = IntegerField('location')
        self.tag = StringField('tag')
        self.amount = IntegerField('amount', validators=[NumberRange(min=0)])
        self.name = StringField('name')
        self.mtime = StringField('mtime')
    tag = StringField('tag')
    minusbuton = SubmitField('minus')
    amount = IntegerField('amount', validators=[NumberRange(min=0)])
    plusbuton = SubmitField('plus')
    goback = SubmitField('back')
    confim = SubmitField('right')
    goahead = SubmitField('ahead')
def import_from_xlsx(file_path):
    with app.app_context():
        db.drop_all()
        db.create_all()
    # 加载Excel工作簿
    wb = load_workbook(filename=file_path, data_only=True)
    # 加载工作簿，设置 data_only=True
    ws = wb.active
    
    # 遍历工作表中的每一行
    for row in ws.iter_rows(min_row=3, values_only=True):  # 假设第一行是标题行
        new_inventory = Inventory(
            sort=row[0],
            location=row[1],
            tag=row[2],
            amount=row[3],

        )
        db.session.add(new_inventory)
    
    # 提交事务
    db.session.commit()

def db_to_turple():
    with app.app_context():
        inventory = Inventory.query.all()
    for e in inventory:
        print(e.sort, e.location, e.tag, e.amount, e.name, e.mtime)
    
@app.route('/upload', methods=['GET', 'POST'])
def upload_form():
    if request.method == 'POST':
        # 文件上传逻辑
        pass
    return render_template('upload.html')

@app.route('/import', methods=['POST'])
def import_file():
    if request.method == 'POST':
        file = request.files['file']
        if file:
            file_path = 'data.xlsx'
            file.save(file_path)
            import_from_xlsx(file_path)
            db_to_turple()
            return '文件导入成功!'
        
    return redirect(url_for('upload_form'))

