# -*- coding: utf-8 -*-
"""
    :author: luffmims
    :url: http://yum2.cc
    :copyright: © 2025 luffmims <luffmims@hotmaill.com>
    :license: MIT, see LICENSE for more details.
"""

# from datetime import datetime

from inventory_check import app, db
from openpyxl import Workbook, load_workbook

class Inventory(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    sort = db.Column(db.Integer)
    location = db.Column(db.Integer, default=0)
    tag = db.Column(db.Text)
    amount = db.Column(db.Integer)
    checked = db.Column(db.Boolean, default=False)
    name = db.Column(db.Text)
    # mtime = db.Column(db.Date)


def import_from_xlsx(file_path):
    with app.app_context():
        db.drop_all()
        db.create_all()
    # 加载Excel工作簿
    wb = load_workbook(filename=file_path, data_only=True)
    # 加载工作簿，设置 data_only=True
    ws = wb.active
    
    # 遍历工作表中的每一行
    for row in ws.iter_rows(min_row=2, values_only=True):  # 假设第一行是标题行
        new_inventory = Inventory(
            sort=row[0],
            location=row[1],
            tag=row[2],
            amount=row[3],
        )
        db.session.add(new_inventory)
    db.session.commit()

"""
This function exports the inventory data from the database to an Excel file named 'checked.xlsx'.
It queries all inventory records, creates a new Excel workbook and sheet named 'Inventory',
sets the column headers, appends each inventory's details to the sheet, and finally saves the workbook.

Parameters:
    None

Returns:
    None
"""
def import_to_xlsx():
    inventorys = Inventory.query.all()  # 查询所有数据, and sort data by sort
    # 创建一个工作簿
    wb = Workbook()
    # 创建一个工作表
    ws = wb.active
    # 设置工作表名称
    ws.title = "Inventory"
    # 设置工作表列名
    ws.append(["sort", "location", "tag", "amount", "name"])
    # 写入数据
    for inventory in inventorys:
        ws.append([inventory.sort, inventory.location, inventory.tag, inventory.amount, inventory.name])
    # 保存工作簿
    wb.save("checked.xlsx")